==> nui_core-0.0.61.tar.gz: lib/ui/component/nui_persistent_bottom_sheet_widget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core_callbacks.dart';

class NUIDraggableSheetUI extends StatefulWidget {
  NUIDraggableSheetUI({@required this.child, this.collapseAtFirst: true, this.collapseRatio: 0.2, this.expandRatio: 0.8});
  final double collapseRatio;
  final double expandRatio;
  final bool collapseAtFirst;
  final NUIWidgetInflater child;
  @override
  State<StatefulWidget> createState() => _NUIDraggableSheetUIState();
}

class _NUIDraggableSheetUIState extends State<NUIDraggableSheetUI> {
  bool _isExpanded = false;
  double _initialExtent;
  BuildContext _draggableSheetContext;

  @override
  void initState(){
    super.initState();
    this._initialExtent = widget.collapseAtFirst == true ? widget.collapseRatio : widget.expandRatio;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: _buildBody(),
    );
  }

  Widget _buildBody() {
    return InkWell(
      onTap: _toggleDraggableScrollableSheet,
      child: DraggableScrollableActuator(
        child: DraggableScrollableSheet(
          key: Key(_initialExtent.toString()),
          minChildSize: widget.collapseRatio,
          maxChildSize: widget.expandRatio,
          initialChildSize: _initialExtent,
          builder: _draggableScrollableSheetBuilder,
        ),
      ),
    );
  }

  void _toggleDraggableScrollableSheet() {
    if (_draggableSheetContext != null) {
      setState(() {
        _initialExtent = _isExpanded ? widget.collapseRatio : widget.expandRatio;
        _isExpanded = !_isExpanded;
      });
      DraggableScrollableActuator.reset(_draggableSheetContext);
    }
  }

  Widget _draggableScrollableSheetBuilder(BuildContext context, ScrollController scrollController) {
    _draggableSheetContext = context;
    return SingleChildScrollView(
      controller: scrollController,
      child: Column(
        children: [
          widget.child(context)
        ]
      ),
    );
  }
}

==> nui_core-0.0.85.tar.gz: lib/ui/component/nui_persistent_bottom_sheet_widget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_core/nui_core_callbacks.dart';

class NUIDraggableSheet extends StatefulWidget {
  NUIDraggableSheet({@required this.child, this.collapseAtFirst: true, this.collapseRatio: 0.2, this.expandRatio: 0.8});
  final double collapseRatio;
  final double expandRatio;
  final bool collapseAtFirst;
  final NUIWidgetInflater child;
  @override
  State<StatefulWidget> createState() => _NUIDraggableSheetState();
}

class _NUIDraggableSheetState extends State<NUIDraggableSheet> {
  bool _isExpanded = false;
  double _initialExtent;
  BuildContext _draggableSheetContext;

  @override
  void initState(){
    super.initState();
    this._initialExtent = widget.collapseAtFirst == true ? widget.collapseRatio : widget.expandRatio;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: _buildBody(),
    );
  }

  Widget _buildBody() {
    return InkWell(
      onTap: _toggleDraggableScrollableSheet,
      child: DraggableScrollableActuator(
        child: DraggableScrollableSheet(
          key: Key(_initialExtent.toString()),
          minChildSize: widget.collapseRatio,
          maxChildSize: widget.expandRatio,
          initialChildSize: _initialExtent,
          builder: _draggableScrollableSheetBuilder,
        ),
      ),
    );
  }

  void _toggleDraggableScrollableSheet() {
    if (_draggableSheetContext != null) {
      setState(() {
        _initialExtent = _isExpanded ? widget.collapseRatio : widget.expandRatio;
        _isExpanded = !_isExpanded;
      });
      DraggableScrollableActuator.reset(_draggableSheetContext);
    }
  }

  Widget _draggableScrollableSheetBuilder(BuildContext context, ScrollController scrollController) {
    _draggableSheetContext = context;
    return SingleChildScrollView(
      controller: scrollController,
      child: Column(
        children: [
          widget.child(context)
        ]
      ),
    );
  }
}
